@@ -1,6 +1,6 @@
 #Copyright ReportLab Europe Ltd. 2000-2017
 #see license.txt for license details
-#history https://bitbucket.org/rptlab/reportlab/history-node/tip/src/reportlab/graphics/charts/legends.py
+#history https://hg.reportlab.com/hg-public/reportlab/log/tip/src/reportlab/graphics/charts/legends.py
 
 __version__='3.3.0'
 __doc__="""This will be a collection of legends to be used with charts."""
@@ -17,7 +17,7 @@ from reportlab.graphics.widgetbase import Widget, TypedPropertyCollection, PropH
 from reportlab.graphics.shapes import Drawing, Group, String, Rect, Line, STATE_DEFAULTS
 from reportlab.graphics.charts.areas import PlotArea
 from reportlab.graphics.widgets.markers import uSymbol2Symbol, isSymbol
-from reportlab.lib.utils import isSeq, find_locals
+from reportlab.lib.utils import isSeq, find_locals, isStr, asNative
 from reportlab.graphics.shapes import _baseGFontName
 from functools import reduce
 from reportlab import xrange
@@ -35,8 +35,8 @@ def _transMax(n,A):
     return X
 
 def _objStr(s):
-    if isinstance(s,str):
-        return s
+    if isStr(s):
+        return asNative(s)
     else:
         return str(s)
 
@@ -631,87 +631,3 @@ class LineLegend(Legend):
         l.height = dy
         l.strokeColor = fillColor
         return l
-
-def sample1c():
-    "Make sample legend."
-
-    d = Drawing(200, 100)
-
-    legend = Legend()
-    legend.alignment = 'right'
-    legend.x = 0
-    legend.y = 100
-    legend.dxTextSpace = 5
-    items = 'red green blue yellow pink black white'.split()
-    items = [(getattr(colors, i), i) for i in items]
-    legend.colorNamePairs = items
-
-    d.add(legend, 'legend')
-
-    return d
-
-
-def sample2c():
-    "Make sample legend."
-
-    d = Drawing(200, 100)
-
-    legend = Legend()
-    legend.alignment = 'right'
-    legend.x = 20
-    legend.y = 90
-    legend.deltax = 60
-    legend.dxTextSpace = 10
-    legend.columnMaximum = 4
-    items = 'red green blue yellow pink black white'.split()
-    items = [(getattr(colors, i), i) for i in items]
-    legend.colorNamePairs = items
-
-    d.add(legend, 'legend')
-
-    return d
-
-def sample3():
-    "Make sample legend with line swatches."
-
-    d = Drawing(200, 100)
-
-    legend = LineLegend()
-    legend.alignment = 'right'
-    legend.x = 20
-    legend.y = 90
-    legend.deltax = 60
-    legend.dxTextSpace = 10
-    legend.columnMaximum = 4
-    items = 'red green blue yellow pink black white'.split()
-    items = [(getattr(colors, i), i) for i in items]
-    legend.colorNamePairs = items
-    d.add(legend, 'legend')
-
-    return d
-
-
-def sample3a():
-    "Make sample legend with line swatches and dasharrays on the lines."
-
-    d = Drawing(200, 100)
-
-    legend = LineLegend()
-    legend.alignment = 'right'
-    legend.x = 20
-    legend.y = 90
-    legend.deltax = 60
-    legend.dxTextSpace = 10
-    legend.columnMaximum = 4
-    items = 'red green blue yellow pink black white'.split()
-    darrays = ([2,1], [2,5], [2,2,5,5], [1,2,3,4], [4,2,3,4], [1,2,3,4,5,6], [1])
-    cnp = []
-    for i in range(0, len(items)):
-        l =  LineSwatch()
-        l.strokeColor = getattr(colors, items[i])
-        l.strokeDashArray = darrays[i]
-        cnp.append((l, items[i]))
-    legend.colorNamePairs = cnp
-    d.add(legend, 'legend')
-
-    return d
